@@ -12,7 +12,7 @@ Example:
 >>> test1.delete()  # dangerous!
 '''
 
-__version__      = '0.5'
+__version__      = '0.6'
 __author__       = 'Volker Grabsch'
 __author_email__ = 'vog@notjusthosting.com'
 __url__          = 'http://www.profv.de/python-vserver/'
@@ -418,7 +418,6 @@ class DebianVServer(object):
             u'-m', mirror,
             u'-d', suite,
         ])
-        self.add_apt_keys(self.read_uri(u'http://backports.org/debian/archive.key'))
         self.apt_sources = (
             (u'deb', mirror,                              u'%s'           % (suite,), u'main contrib non-free'),
             (u'deb', u'http://security.debian.org/',      u'%s/updates'   % (suite,), u'main contrib non-free'),
@@ -435,7 +434,7 @@ class HostingVServer(object):
         self.p = DebianVServer(name)
 
     def build(self, ip, fqdn, mirror, timezone):
-        self.p.build(ip, fqdn, mirror, u'lenny')
+        self.p.build(ip, fqdn, mirror, u'squeeze')
         self.p.start_on_boot = True
         self.p.timezone = timezone
         self.p.set_user_password(u'root', None)
@@ -454,7 +453,7 @@ class HostingVServer(object):
             u'ffmpeg', u'ffmpeg2theora',
         )
         running_services = self.p.running_services
-        if len(running_services) != 4:
+        if len(running_services) != 5:
             raise Error(u'Unexpected running services:\n%s',
                         u'\n'.join(running_services))
 
@@ -553,8 +552,9 @@ class HostingVServer(object):
             u'libmailtools-perl', u'libnet-dns-perl', u'libnet-ip-perl', u'libnet-smtpauth-perl',
             u'libwww-perl', u'libxml-perl', u'libxml-parser-perl', u'libxml-libxml-perl',
             u'python-4suite', u'python-egenix-mxdatetime', u'python-egenix-mxtools', u'python-flup',
-            u'python-ldap', u'python-mysqldb', u'python-pgsql', u'python-psyco', u'python-psycopg2',
-            u'python-pyopenssl', u'python-tz', u'python-unit', u'python-webpy', u'python-xml',
+            u'python-ldap', u'python-mysqldb', u'python-pgsql', u'python-pip', u'python-psyco',
+            u'python-psycopg2', u'python-pyopenssl', u'python-tz', u'python-unit',
+            u'python-virtualenv', u'python-webpy', u'python-xml',
             u'ruby', u'ruby-dev', u'irb', u'rdoc',
             u'libfcgi-ruby', u'libyaml-ruby', u'libzlib-ruby', u'libopenssl-ruby', u'liberb-ruby',
             u'libdbd-mysql-ruby', u'libdbd-pg-ruby', u'libdbd-sqlite3-ruby', u'libtermios-ruby',
@@ -580,6 +580,11 @@ class HostingVServer(object):
         self.p.p.write(u'/etc/apache2/conf.d/charset', 0644,
             u'#AddDefaultCharset UTF-8\n'
         )
+        self.p.p.write(u'/etc/apache2/mods-available/dir.conf', 0644,
+            u'<IfModule mod_dir.c>\n'
+            u'    DirectoryIndex index.html index.wsgi index.fcgi index.cgi index.pl index.php index.xhtml index.htm\n'
+            u'</IfModule>\n'
+        )
         self.p.p.write(u'/etc/apache2/mods-available/fcgid.conf', 0644,
             u'<IfModule mod_fcgid.c>\n'
             u'    AddHandler fcgid-script .fcgi\n'
@@ -596,6 +601,7 @@ class HostingVServer(object):
         self.p.p.write(u'/etc/php5/conf.d/local_settings.ini', 0644,
             u'memory_limit = 256M\n'
         )
+        self.p.set_apache_module_enabled(u'expires', True)
         self.p.set_apache_module_enabled(u'fcgid',   True)
         self.p.set_apache_module_enabled(u'include', True)
         self.p.set_apache_module_enabled(u'php5',    True)
